# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .wdr_report import WdrReport as WdrReport
from .detail_records_report_list_params import DetailRecordsReportListParams as DetailRecordsReportListParams
from .detail_records_report_create_params import DetailRecordsReportCreateParams as DetailRecordsReportCreateParams
from .detail_records_report_list_response import DetailRecordsReportListResponse as DetailRecordsReportListResponse
from .detail_records_report_create_response import (
    DetailRecordsReportCreateResponse as DetailRecordsReportCreateResponse,
)
from .detail_records_report_delete_response import (
    DetailRecordsReportDeleteResponse as DetailRecordsReportDeleteResponse,
)
from .detail_records_report_retrieve_response import (
    DetailRecordsReportRetrieveResponse as DetailRecordsReportRetrieveResponse,
)
