# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["AvailablePhoneNumbersMetadata"]


class AvailablePhoneNumbersMetadata(BaseModel):
    best_effort_results: Optional[int] = None

    total_results: Optional[int] = None
