# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict
from typing_extensions import TypeAlias

__all__ = ["CampaignGetOperationStatusResponse"]

CampaignGetOperationStatusResponse: TypeAlias = Dict[str, object]
