# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .call_fork_started import CallForkStarted

__all__ = ["CallForkStartedWebhookEvent"]


class CallForkStartedWebhookEvent(BaseModel):
    data: Optional[CallForkStarted] = None
